@@ -16,7 +16,6 @@ from fmdt.args import (
     Args,
     DetectArgs,
     VisuArgs,
-    Video,
     detect_args
 )
 
@@ -35,21 +34,32 @@ from fmdt.truth import (
 
 from fmdt.download import (
     download_csvs,
-    download_demo_mp4
+    download_demo_mp4,
+    download_dbs
 )
 
 from fmdt.config import (
     init,
     load_gt12,
     load_gt6,
+    load_config,
     get_draco12,
     get_draco6
 )
 
+from fmdt.db import (
+    Video,
+    VideoType,
+    load_in_videos,
+    load_draco6,
+    load_draco12,
+    load_window
+)
+
 # from fmdt.truth import HumanDetection
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 0
-PATCH         = 25
+PATCH         = 27
 
 VERSION = str(MAJOR_VERSION) + "." + str(MINOR_VERSION) + "." + str(PATCH)
