@@ -30,75 +30,6 @@ def row_to_dict(row: pd.Series) -> dict:
             out[k] = row[k]
     
     return out
-
-class VideoType(Enum):
-    DRACO6 = 0,
-    DRACO12 = 1,
-    WINDOW = 2
-
-    def __str__(self) -> str:
-        if self == VideoType.DRACO6:
-            return "DRACO6"
-        elif self == VideoType.DRACO12:
-            return "DRACO12"
-        else:
-            return "WINDOW"
-        
-    def __repr__(self) -> str:
-        return self.__str__()
-    
-    @staticmethod
-    def from_str(str):
-        if str == "DRACO6":
-            return VideoType.DRACO6 
-        elif str == "DRACO12":
-            return VideoType.DRACO12
-        else:
-            return VideoType.WINDOW
-
-# Or maybe recording, night sky watching, stargazing, video of night sky
-# type is an enum { draco6, draco12, window}
-class Video:
-
-    csv_hdr = "id,name,type\n"
-    
-    def __init__(self, name: str, type: VideoType = None):
-        self.name = name
-        self.type = type
-
-    def to_csv(self) -> str:
-        return f"{self.name},{self.type}\n"
-    
-    def __str__(self) -> str:
-        return f"{self.name}"
-    
-    def __repr__(self) -> str:
-        return self.__str__()
-    
-    @staticmethod
-    def from_pd_row(ser: pd.Series):
-        out = Video(ser["name"], VideoType.from_str(ser["type"]))
-        return out
-
-# Take a list of Videos and turn it into a data base.
-def videos_to_csv(videos: list[Video], csv_filename: str) -> None:
-    # First get the header
-    hdr = "id,name,type\n"
-
-    with open(csv_filename, "w") as csv:
-        csv.write(hdr)
-        
-        i = 0
-        for v in videos:
-            csv.write(f"{i},{v.name},{v.type}\n")
-            i += 1
-
-def csv_to_videos(csv_filename: str) -> list[Video]:
-
-    df = pd.read_csv(csv_filename)
-    return [Video.from_pd_row(df.iloc[i]) for i in range(len(df))]
-
-
     
 class DetectArgs:
 
