@@ -1,3 +1,5 @@
+"""Convert the contents of `human_detectsions.csv` and `test_vid.csv` into a single data base file `videos.db`"""
+
 import sqlite3 
 import pandas as pd
 from fmdt.args import *
@@ -39,21 +41,21 @@ csv_file = "human_detections.csv"
 
 df_gt = pd.read_csv(csv_file)
 
-cur.execute("CREATE TABLE human_detection(id, video_name, start_x, start_y, start_f, end_x, end_y, end_f)")
+cur.execute("CREATE TABLE human_detection(id, video_name, start_x, start_y, start_frame, end_x, end_y, end_frame)")
 for i in range(len(df_gt)):
     r = df_gt.iloc[i]
 
     vid_name = r["video_name"]
     start_x = r["start_x"]
     start_y = r["start_y"]
-    start_f = r["start_frame"]
+    start_frame = r["start_frame"]
     end_x = r["end_x"]
     end_y = r["end_y"]
-    end_f = r["end_frame"]
+    end_frame = r["end_frame"]
 
     cur.execute(f"""
     INSERT INTO human_detection VALUES 
-        ({i}, '{vid_name}', {start_x}, {start_y}, {start_f}, {end_x}, {end_y}, {end_f})
+        ({i}, '{vid_name}', {start_x}, {start_y}, {start_frame}, {end_x}, {end_y}, {end_frame})
     """)
 
 con.commit()
